/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration CEC :
    
    MCU             : CEC1702
    Dev. Board      : Clicker 2 for CEC1702
    SW              : mikroC PRO for ARM v5.1.0

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/

sbit MUX_A0_PIN at GPIO_OUTPUT_040_047.B5; 

sbit BUCK_ENABLE_PIN at GPIO_OUTPUT_000_007.B3; 

sbit MUX_A1_PIN at GPIO_OUTPUT_130_137.B4; 

sbit PG_PIN at GPIO_INPUT_030_037.B0; 

void systemInit()
{
    GPIO_OUTPUT_130_137 = 0;
    GPIO_OUTPUT_130_137.B5 = 0;
    delay_ms(100);
    GPIO_OUTPUT_130_137.B5 = 1;
    delay_ms(100);

    Delay_ms (1000);
    UART1_Init_Advanced( 9600, _UART_8_BIT_DATA, _UART_NOPARITY,
                         _UART_ONE_STOPBIT );

    Delay_ms(100);
}

void Buck_Init()
{
    Gpio_Digital_Output(&GPIO_PORT_040_047, _GPIO_PINMASK_5);
    Gpio_Digital_Output(&GPIO_PORT_000_007, _GPIO_PINMASK_3);
    Gpio_Digital_Output(&GPIO_PORT_130_137, _GPIO_PINMASK_4);
    Gpio_Digital_Input (&GPIO_PORT_030_037, _GPIO_PINMASK_0);
    BUCK_ENABLE_PIN = 1;
    MUX_A0_PIN = 0;
    MUX_A1_PIN = 0; 
}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART1_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART1_Write_Text( "\r\n" );
        delay_ms(1000);
    }

}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
    	Buck_Task();
    }
}


