/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration STM32 :
    
    MCU             : STM32F107VCT6
    Dev. Board      : EasyMx PRO v7 for STM32 ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/

sbit MUX_A0_PIN at GPIOC_ODR.B2;

sbit BUCK_ENABLE_PIN at GPIOD_ODR.B13;

sbit MUX_A1_PIN at GPIOA_ODR.B0;

sbit PG_PIN at GPIOD_IDR.B10;

void systemInit()
{
    UART1_Init(9600);
}

void Buck_Init()
{
    GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    GPIO_Digital_Output( &GPIOD_BASE, _GPIO_PINMASK_13 );
    GPIO_Digital_Output( &GPIOA_BASE, _GPIO_PINMASK_0 );
    GPIO_Digital_Input ( &GPIOD_BASE, _GPIO_PINMASK_10 );
    BUCK_ENABLE_PIN = 1;
    MUX_A0_PIN = 0;
    MUX_A1_PIN = 0;   
}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART1_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART1_Write_Text( "\r\n" );
        delay_ms(1000);
    }

}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
    	Buck_Task();
    }
}